@@ -29,7 +29,7 @@
 #include <kio/slavebase.h>
 
 class QCString;
-namespace jstreams {
+namespace Strigi {
     class ArchiveReader;
 }
 class QFileStreamOpener;
@@ -37,7 +37,7 @@ class QFileStreamOpener;
 class kio_jstreamProtocol : public KIO::SlaveBase
 {
 private:
-    jstreams::ArchiveReader* reader;
+    Strigi::ArchiveReader* reader;
     QFileStreamOpener* opener;
 
     KIO::UDSEntry statQFileInfo(const QFileInfo& f) const;
