@@ -24,10 +24,10 @@
 #include <indexable.h>
 #include <extractor.h>
 
-using namespace jstreams;
+using namespace Strigi;
 using namespace std;
 
-class ExtractorEndAnalyzer : public jstreams::StreamEndAnalyzer {
+class ExtractorEndAnalyzer : public StreamEndAnalyzer {
 private:
     static int objectCount;
     static EXTRACTOR_ExtractorList *extractors;
@@ -35,9 +35,9 @@ public:
     ExtractorEndAnalyzer();
     ~ExtractorEndAnalyzer();
     bool checkHeader(const char* header, int32_t headersize) const;
-    char analyze(jstreams::Indexable& idx, jstreams::InputStream* in);
-    static char staticAnalyze(std::string filename, jstreams::InputStream *in,
-        int depth, jstreams::StreamIndexer *indexer, jstreams::Indexable*);
+    char analyze(Indexable& idx, InputStream* in);
+    static char staticAnalyze(std::string filename, InputStream *in,
+        int depth, StreamIndexer *indexer, Indexable*);
     const char* getName() const { return "ExtractorEndAnalyzer"; }
 };
 
@@ -60,7 +60,7 @@ ExtractorEndAnalyzer::checkHeader(const char* /*header*/,
     return true;
 }
 char
-ExtractorEndAnalyzer::analyze(jstreams::Indexable& idx, InputStream *in) {
+ExtractorEndAnalyzer::analyze(Indexable& idx, InputStream *in) {
     int32_t size = 20000;
     const char* b;
     int32_t nread = in->read(b, size, size);
